* COMMON VARIABLES FOR TOMCAT TC68 
* Hardware Addresses, RAM variables, and constants
* HARDWARE: REV 1
*===============================================================================

* MACROS (These are necessary in order to use Absolute Short addressing.)

DSB:	MACRO			* Assign Byte(s), using Equates.
\1	EQU	CURR
CURR	SET	CURR+\2
	ENDM

DSW:	MACRO			* Assign Word(s), using Equates.
\1	EQU	CURR
CURR	SET	CURR+\2*2
	ENDM

DSL:	MACRO			* Assign Long Word(s), using Equates.
\1	EQU	CURR
CURR	SET	CURR+\2*4
	ENDM

ALIGN:	MACRO			* Align to an even byte address
	IFNE	CURR/2*2-CURR
CURR	SET	CURR+1
	ENDC
	ENDM

*===========================================================================
*Hardware Addresses:

LNKRD	EQU	$400000		*R	Read Game Link Data

ADCREAD	EQU	$402000		*R	Read A/D Converter Output
*===============================================================================
INPUTS	EQU	$404000		*R	Inputs

*		D15	/L THUMB		D7	/DSW 7
*		D14	/R THUMB		D6	/DSW 6
*		D13	/L FIRE			D5	/DSW 5
*		D12	/R FIRE			D4	/DSW 4
*		D11	/SELF TEST		D3	/DSW 3	
*		D10	/DIAGN.			D2 	/DSW 2
*		D9	/SPARE			D1 	/DSW 1
*		D8	VGHALT			D0	/DSW 0

OSW2	EQU	$0	* (# for BTST instruction)
OSW4	EQU	$1
OSW6	EQU	$2
OSW8	EQU	$3
OSW7	EQU	$4
OSW5	EQU	$5
OSW3	EQU	$6
OSW1	EQU	$7
*===============================================================================
PRNG	EQU	$406000		*R	Read Pseudo-Random-Number Generator

IN1	EQU	$408000		*R	More Inputs

*		D15	LNKFLAG		(Game Link)
*		D14	PC3		   "    "
*		D13	PC2		   "    "
*		D12	PC0		   "    "
*		D11	MAINFLAG	(Sound System)
*		D10	SOUNDFLAG	   "    "
*		D9	/IDLE*		(TMS320 System)
*		D8

MBIOH 	EQU	$40A000		*R  	TMS-320 BIO(on) 

MAINRD	EQU	$40C000		*R	Read Sound Interface Data

PRNGCLR EQU	$40E000		*R	Clear the PRNG
*===============================================================================
LNKWR	EQU	$400000		*W	Write Game Link Data

ADCON	EQU	$402000		*W	A/D Control: Set up address, 
*					then D3 high, then D3 low 
*	D0	ADDA
*	D1	ADDB
*	D2	ADDC
*	D3	ALE/START

VGGO	EQU	$404000		*W  Start Vector Generator   (Address Strobe)

VGRES	EQU	$406000		*W  Reset Vector Generator   (Address Strobe)

WDCLR	EQU	$408000		*W  Clear Watch Dog Timer    (Address Strobe)

IRQCLR	EQU	$40A000		*W  Clear IRQ Latch          (Address Strobe)
	
MAINWR	EQU	$40C000		*W  Write Sound Interface Data (Address Strobe)

LED1ON	EQU	$40E000		*W  LED 1 On		     (Address Strobe)
LED2ON	EQU	$40E002		*W  LED 2 On		     (Address Strobe)
MRESL 	EQU	$40E004		*W  320 Reset Low	     (Address Strobe)
SNDRESL	EQU	$40E006		*W  Sound Reset Low	     (Address Strobe)
LNKMODEL EQU	$40E008		*W  Link Mode Low	     (Address Strobe)
ERRL	EQU	$40E00A		*W  Link Error Flag Low	     (Address Strobe)
ACKL	EQU	$40E00C		*W  Link ACK Flag Low	     (Address Strobe)
TXBUFFL	EQU	$40E00E		*W  Link Buffer Control	     (Address Strobe)
	
LED1OFF	EQU	$40E010		*W  LED 1 Off		     (Address Strobe)
LED2OFF	EQU	$40E012 	*W  LED 2 Off		     (Address Strobe)
MRESH	EQU	$40E014		*W  320 Reset high	     (Address Strobe)
SNDRESH	EQU	$40E016		*W  Sound Reset high	     (Address Strobe)
LNKMODEH EQU	$40E018		*W  Link Mode high	     (Address Strobe)
ERRH	EQU	$40E01A		*W  Link Error Flag high     (Address Strobe)
ACKH	EQU	$40E01C		*W  Link ACK Flag high	     (Address Strobe)
TXBUFFH	EQU	$40E01E		*W  Link Buffer Control high (Address Strobe)
*===============================================================================
VMEM	EQU	$800000		*16K Bytes  80000-83FFF

M_320	EQU	$0FFFFA000	* TMS320 RAM (8K bytes, from $0FFA000 to 
*								$0FFBFFF)
RAM	EQU	$0FFFFC000	* 8K Bytes   0FFC000-0FFDFFF	
USTACK  EQU	$0FFFFD000	* User Stack
*===========================================================================
* RAM variables will be addressed in Absolute Short mode.
*
* In order for the assembler to recognize Absolute Short Negative, the address
* must be sign extended to 32 bits. Example: FFFFC000 instead of 00FFC000
CURR	SET	RAM		* RAM Hardware Address

* The First 32 bytes are reserved for stuff that will not be cleared at the
* beginning of each game.
	DSW	GLINK,1		* Game Link Flag, 1 = Linked
	DSW	CMODE,1		* Control Mode, 1 = Manual, 0 = Computer Assist
	DSW	STFLAG,1	* 'Start' Flag, 1 = Start
	DSW	LNKERRS,1	* Link Errors
	DSW	MISSION,1
	DSW	CRAFT,1

CURR	SET	RAM+32
	DSW	XP,1
	DSW	YP,1
	DSW	ZP,1
	DSW	COUNT,1
	DSW	PZ1,1		*Horizon
	DSW	PY1,1		*Horizon
	DSW	PZ2,1		*Horizon
	DSW	PY2,1		*Horizon
	DSW	A_HDN,1		*Heading Angle (Bin * 10)
	DSW	A_HDND,1	*Heading Angle (BCD * 10)
	DSW	ASPD,1		*Airspeed
	DSW	T_CNT,1		*Count of Terrain Object locations remaining 

	DSL	T_PTR,1		*Pointer to table of Terrain Object Locations
	DSL	T_LOC,1		*Terrain Object Pointer
	DSL	VG_PTR,1	*VG address pointer
	DSL	MODEL,1		*Subroutine address for different test objects

	DSB	STAT,1		*STAT Instruction immediate value
	DSB	BRITE,1		* Intensity 0-80
	DSB	COLOR,1		*D2=RED, D1=GREEN, D0=BLUE
	DSB	ZSTAT,1		*INTENSITY = Z(vector) * ZSTAT
	DSB	VBIN,1		*BINARY MULTIPLIER, 3 BITS, 2**(1-BIN)
	DSB	VLIN,1		*LINEAR MULTIPLIER, 8 NITS,1-(LIN/255)
	DSB	RPOT0,1		*Raw Value of Pot 0	
	DSB	RPOT1,1		*Raw Value of Pot 1
	DSB	RPOT2,1		*Raw Value of Pot 2
	DSB	RPOT3,1		*Raw Value of Pot 3
	DSB	RPOT4,1		*Raw Value of Pot 4
	DSB	RPOT5,1		*Raw Value of Pot 5
	DSB	POT0,1		*Adjusted Value of Pot 0
	DSB	POT1,1		*Adjusted Value of Pot 1
	DSB	POT2,1		*Adjusted Value of Pot 2
	DSB	POT3,1		*Adjusted Value of Pot 3
	DSB	T_COUNT,1	*Count of Terrain Objects	
	DSB	IRQFRAME,1	*IRQ Frame number, 0 - 3
	DSB	BUFFER,1	* 0 or 1 = Even or Odd
	DSB	FRAME,2		* 1 = new data frame is ready
	DSB	STRBTIME,1	* For Runway Strobe Lights, Flashing Timer
	DSB	STRBNUM,1	* Runway Strobe Lights
	DSB	STAT1,1		* Staus word for clipping
	DSB	STAT2,1		* Staus word for clipping

	ALIGN			* To make the bytes come out even	
*===============================================================================
* UNIT VECTORS

AX 	EQU	$00	* (Word) 	unit vector coefficients
BX  	EQU 	$02   	* (Word)	     "
CX  	EQU 	$04	* (Word)	     "
AY  	EQU 	$06	* (Word)	     "
BY 	EQU 	$08	* (Word)	     "
CY 	EQU 	$0A	* (Word)	     "
AZ 	EQU 	$0C	* (Word)	     "
BZ 	EQU 	$0E	* (Word)	     "
CZ 	EQU 	$10	* (Word)	     "
XT 	EQU 	$12	* (Word)  	translation	(where used)
YT 	EQU 	$14	* (Word)	     "
ZT 	EQU 	$16	* (Word)	     "
VX 	EQU 	$18	* (Long Word)   velocity	(where used)
VY 	EQU 	$1C	* (Long Word)	     "
VZ 	EQU 	$20	* (Long Word)	     "
FX 	EQU 	$24	* (Word)  	acceleration	(where used)
FY 	EQU 	$26	* (Word)	     "
FZ 	EQU 	$28	* (Word)	     "
THRUST	EQU	$2A	* (Word)     	  thrust	(where used)

R_ANGLE EQU	$12	*   running sum of Roll Angle Tics  (where used)
P_ANGLE EQU	$14	*   running sum of Pitch Angle Tics (where used)
Y_ANGLE EQU	$16	*   running sum of Yaw Angle Tics   (where used)

	DSW	UV1,12		* Ship 1 Primary Unit Vectors:  
*			   	AX,AY,AZ,BX,BY,BZ,CX,CY,CZ
*			   	R_ANGLE,P_ANGLE,Y_ANGLE

	DSW	UV2,22		* Ship 1 Working Copy:  
*			   	AX,AY,AZ,BX,BY,BZ,CX,CY,CZ,
*			   	XT,YT,ZT,VX.L,VY.L,VZ.L,FX,FY,FZ,THRUST
*
	DSW	UV3,12		* Ship 2 Primary Unit Vectors:  
*			   	AX,AY,AZ,BX,BY,BZ,CX,CY,CZ
*			   	R_ANGLE,P_ANGLE,Y_ANGLE

	DSW	UV4,22		* Ship 2 Working Copy:  
*			   	AX,AY,AZ,BX,BY,BZ,CX,CY,CZ,
*			   	XT,YT,ZT,VX.L,VY.L,VZ.L,FX,FY,FZ,THRUST

	DSW	CCUV,12		* Concatenated Unit Vectors: 
*			   	AX,AY,AZ,BX,BY,BZ,CX,CY,CZ,XT,YT,ZT

*===============================================================================
	DSW	PTBL,128	*Point Table for transformed and projected points;
*			 	Used by Vector Drawing Routines;
*			 	64 points * 2 words = 128 words

	DSW	TOBJ,36		*Point Table for Rotated Terrain Objects;
*			 	12 points * 3 words = 36 words

	DSW	XR,1		* Used in generating the runway
	DSW	YR,1
	DSW	ZR,1
	DSW	TX,1
	DSW	TY,1
	DSW	TZ,1
* GUNS
	DSB	G_DATA,16*GBLK   16 Gun Blocks (of memory [bytes])
	DSB	G_PTS,1
	DSB	G_RDY,1
	DSB	G_COUNT,1
	DSB	GLOW,1
	DSW	CURRX,1	
	DSW	CURRY,1

GFLAG	EQU	$0	* .W
GXT	EQU	$2	* .L
GYT	EQU	$6	* .L
GZT	EQU	$0A	* .L
GVX	EQU	$0E	* .L
GVY	EQU	$12	* .L
GVZ	EQU	$16	* .L
GBLK	EQU	26	* There are 26 Bytes in a Gun Block (of memory) 
GMAX	EQU	8	* Restrict the number of shots
*===============================================================================
* Aero stuff, hopefully temporary
	DSL	FX1,1
	DSL	FY1,1
	DSL	FZ1,1
	DSL	VX1,1
	DSL	VY1,1
	DSL	VZ1,1
	DSL	XT1,1
	DSL	YT1,1
	DSL	ZT1,1

	DSL	FX2,1
	DSL	FY2,1
	DSL	FZ2,1
	DSL	VX2,1
	DSL	VY2,1
	DSL	VZ2,1
	DSL	XT2,1
	DSL	YT2,1
	DSL	ZT2,1
*===============================================================================
	DSB	S1HITS,1	* Ship 1 Hits
	DSB	S2HITS,1	* Ship 2 Hits
	DSB	S1CFLAG,1	* Ship 1 Crash Flag	0 = no crash
	DSB	S2CFLAG,1	* Ship 2 Crash Flag	0 = no crash
*===============================================================================
* Tracer Buffers For Linked Games
	DSW	TRIN,(16*3+1)	* Tracer Input Buffer
	DSW	TROUT,(16*3+1)	* Tracer Output Buffer
*===============================================================================
	DSL	FUEL,1		* 
	DSW	OBJSEL,1	* Object Select Index Number
	DSL	MONPTR,1	* Monitor Test Pattern Routine Pointer
*===============================================================================
* POINT LABELS

* WITHIN THE OBJECT POINT LIBRARY (BYTES)
X  	EQU	0
Y  	EQU	2
Z  	EQU	4

* Point Table PTBL (projected points waiting to be formatted for
* the Vector Generator) uses only X and Y

*===========================================================================
* Variables for TMS320

M_PROG	EQU	M_320+$0008	* First location of executable code

M_OUTL EQU	M_320+$1400	* Output List (512 words = 170 points, 
*							   256 projected)

M_OBJ	EQU	M_320+$1800	* Object Library (1024 words = 341 points)
*				 (program must end before 320 adr = 0C00

CURR	SET 	M_320+$0C

	DSW	numera,1
	DSW	denom,1
	DSW	quot,1
	DSW	temsgn,1
	DSW	m_xp,1
	DSW	m_yp,1
	DSW	m_zp,1
	DSW	m_sx,1
	DSW	m_sy,1
	DSW	m_x,1
	DSW	m_y,1
	DSW	m_z,1
	DSW	m_one,1
	DSW	m_mask,1
	DSW	m_tptr,1
	DSW	m_uv,1
	DSW	m_sin,1
	DSW	m_cos,1

	DSW	m_ccuv,12
	DSW	m_uv1,12
	DSW	m_uv2,12
	DSW	m_ps1,12	* Primary Set 1
	DSW	m_wc1,12	* Working Copy 1
	DSW	m_ps2,12	* Primary Set 2
	DSW	m_wc2,12	* Working Copy 2

	DSW	m_gspace,1
	DSW	m_x1,1
	DSW	m_y1,1
	DSW	m_z1,1
	DSW	m_x2,1
	DSW	m_y2,1
	DSW	m_z2,1
	DSW	m_xmin,1
	DSW	m_tcount,1
	DSW	m_stat1,1
	DSW	m_stat2,1
	DSW	m_flag,1

	DSW	m_pcount,1
	DSW	m_ocount,1
	DSW	m_optr,1

* TMS320 Program Addresses 
M_DIV1		EQU	$0080
M_PROJ		EQU	$0096
M_PDIV		EQU	$00A0

M_TEST1 	EQU	$00C2		* Test Data transfer 
M_TEST2 	EQU	$00CA		* Test DNL1 and UPL1
M_TEST3 	EQU	$00D6		* Test DIV1

M_INIT		EQU	$00E0

M_DNL1		EQU	$00EB
M_DNL2		EQU	$00EE
M_UPL1		EQU	$010A
M_UPL2		EQU	$0110

M_POST1 	EQU	$0158
M_PCON1		EQU	$0161
M_POST2		EQU	$0167
M_PCON2		EQU	$0170
M_POST3		EQU	$0178
M_PCON3		EQU	$0181
M_CONCAT 	EQU	$018B
M_ROLL		EQU	$01B3
M_PITCH 	EQU	$01FE
M_YAW		EQU	$0249
M_PRESUB 	EQU	$0294
M_PRECON	EQU	$029D
M_CLIP		EQU	$02BC
M_SPRESUB	EQU	$046A
M_POST4		EQU	$04AB
M_PRE2		EQU	$04DB

* TMS-320 Memory:
*
*	     0 - 7	Idle Loop		[4 words]
*	     8 - 0B 	Branch Instruction   	[2 words]
*	    0C - 0FF 	Direct Ram		[122 words]
*	   100 - 13FF 	Program			[2432 words]
*	  1400 - 17FF 	Output Buffer		[512 words]
*	  1800 - 1FFF 	Object Pictures 	[1024 words]
